==> zola-0.19.0.tar.gz: zola-0.19.0/docs/content/themes/zola-minimal/index.md <==

+++
title = "Minimal"
description = "📚 Minimal is a Zola port of the Jekyll theme with the same name."
template = "theme.html"
date = 2024-06-13T08:07:01-05:00

[extra]
created = 2024-06-13T08:07:01-05:00
updated = 2024-06-13T08:07:01-05:00
repository = "https://github.com/semanticdata/zola-minimal.git"
homepage = "https://github.com/semanticdata/zola-minimal/"
minimum_version = "0.18.0"
license = "MIT"
demo = "https://zola-minimal.vercel.app/"

[extra.author]
name = "Miguel Pimentel"
homepage = "https://miguelpimentel.do/"
+++        

<div align="center">
<h1>📚 Minimal</h1>
  <img src="https://img.shields.io/github/languages/code-size/semanticdata/zola-minimal" />
  <img src="https://img.shields.io/github/repo-size/semanticdata/zola-minimal" />
  <img src="https://img.shields.io/github/commit-activity/t/semanticdata/zola-minimal" />
  <img src="https://img.shields.io/github/last-commit/semanticdata/zola-minimal" />
  <img src="https://img.shields.io/website/https/zola-minimal.vercel.app.svg" />
</div>

<div align="center">

[Minimal](https://zola-minimal.vercel.app/) is a [Zola](https://www.getzola.org) theme with the goal of helping you build a light, fast, and SEO ready landing page or website.

It is based on the [Jekyll](https://jekyllrb.com/) theme with [the same name](https://github.com/pages-themes/minimal).

Check out the [demo](https://zola-minimal.vercel.app/).

</div>

![theme screenshot](screenshot.png)

## 🚀 Quick Start

Before using the theme, you need to install [Zola](https://www.getzola.org/documentation/getting-started/installation/) ≥ v0.18.0.

```sh
# 1. Clone the repo
git clone git@github.com:semanticdata/zola-minimal.git

# 2. Change directory into clone
cd zola-minimal

# 3. Serve the site locally
zola serve

# 4. Open http://127.0.0.1:1111/ in the browser
```

For more detailed instructions, visit the [Documentation](https://www.getzola.org/documentation/themes/installing-and-using-themes/) page about installing and using themes.

## 🎨 Customization

You can change the configuration, templates and content yourself. Refer to the [config.toml](config.toml), and [templates](templates) for ideas. In most cases you only need to modify the contents of [config.toml](config.toml) to customize the appearance of your blog. Make sure to visit the Zola [Documentation](https://www.getzola.org/documentation/getting-started/overview/).

Adding custom CSS is as easy as adding your styles to [sass/_custom.scss](sass/_custom.scss). This is made possible because SCSS files are backwards compatible with CSS. This means you can type normal CSS code into a SCSS file and it will be valid.

## 🚩 Reporting Issues

We use GitHub Issues as the official bug tracker for **Minimal**. Please search [existing issues](https://github.com/semanticdata/zola-minimal/issues). It’s possible someone has already reported the same problem. If your problem or idea is not addressed yet, [open a new issue](https://github.com/semanticdata/zola-minimal/issues/new).

## 💜 Acknowledgements

Zola Minimal is a fork of the Jekyll theme [Minimal](https://github.com/pages-themes/minimal).

## © License

Source code in this repository is available under the [MIT License](LICENSE).

==> zola-0.19.1.tar.gz: zola-0.19.1/docs/content/themes/zola-minimal/index.md <==

+++
title = "Minimal"
description = "📚 Minimal is a Zola port of the Jekyll theme with the same name."
template = "theme.html"
date = 2024-06-24T05:58:05Z

[extra]
created = 2024-06-24T05:58:05Z
updated = 2024-06-24T05:58:05Z
repository = "https://github.com/semanticdata/zola-minimal.git"
homepage = "https://github.com/semanticdata/zola-minimal/"
minimum_version = "0.18.0"
license = "MIT"
demo = "https://zola-minimal.vercel.app/"

[extra.author]
name = "Miguel Pimentel"
homepage = "https://miguelpimentel.do/"
+++        

<div align="center">
<h1>📚 Minimal</h1>
  <img src="https://img.shields.io/github/languages/code-size/semanticdata/zola-minimal" />
  <img src="https://img.shields.io/github/repo-size/semanticdata/zola-minimal" />
  <img src="https://img.shields.io/github/commit-activity/t/semanticdata/zola-minimal" />
  <img src="https://img.shields.io/github/last-commit/semanticdata/zola-minimal" />
  <img src="https://img.shields.io/website/https/zola-minimal.vercel.app.svg" />
</div>

<div align="center">

[Minimal](https://zola-minimal.vercel.app/) is a [Zola](https://www.getzola.org) theme with the goal of helping you build a light, fast, and SEO ready landing page or website.

It is based on the [Jekyll](https://jekyllrb.com/) theme with [the same name](https://github.com/pages-themes/minimal).

Check out the [demo](https://zola-minimal.vercel.app/).

</div>

![theme screenshot](screenshot.png)

## 🚀 Quick Start

Before using the theme, you need to install [Zola](https://www.getzola.org/documentation/getting-started/installation/) ≥ v0.18.0.

```sh
# 1. Clone the repo
git clone git@github.com:semanticdata/zola-minimal.git

# 2. Change directory into clone
cd zola-minimal

# 3. Serve the site locally
zola serve

# 4. Open http://127.0.0.1:1111/ in the browser
```

For more detailed instructions, visit the [Documentation](https://www.getzola.org/documentation/themes/installing-and-using-themes/) page about installing and using themes.

## 🎨 Customization

You can change the configuration, templates and content yourself. Refer to the [config.toml](config.toml), and [templates](templates) for ideas. In most cases you only need to modify the contents of [config.toml](config.toml) to customize the appearance of your blog. Make sure to visit the Zola [Documentation](https://www.getzola.org/documentation/getting-started/overview/).

Adding custom CSS is as easy as adding your styles to [sass/_custom.scss](sass/_custom.scss). This is made possible because SCSS files are backwards compatible with CSS. This means you can type normal CSS code into a SCSS file and it will be valid.

## 🚩 Reporting Issues

We use GitHub Issues as the official bug tracker for **Minimal**. Please search [existing issues](https://github.com/semanticdata/zola-minimal/issues). It’s possible someone has already reported the same problem. If your problem or idea is not addressed yet, [open a new issue](https://github.com/semanticdata/zola-minimal/issues/new).

## 💜 Acknowledgements

Zola Minimal is a fork of the Jekyll theme [Minimal](https://github.com/pages-themes/minimal).

## © License

Source code in this repository is available under the [MIT License](LICENSE).
